@@ -5,8 +5,13 @@ from .user import User
 
 
 class Conversation(BaseModelAbstract, models.Model):
-    participants = models.ManyToManyField(
-        User, related_name="conversations"
+    user1 = models.ForeignKey(
+        User, models.SET_NULL, related_name="chat_user1_set",
+        null=True, blank=True
+    )
+    user2 = models.ForeignKey(
+        User, models.SET_NULL, related_name="chat_user2_set",
+        null=True, blank=True
     )
 
     class Meta:
